From 0ef92be8ebf9d852206b4457217335db60324956 Mon Sep 17 00:00:00 2001
From: ram <ram>
Date: Fri, 8 Feb 1991 16:38:58 +0000
Subject: [PATCH] Added new header with RCS FILE-COMMENT.

---
 hemlock/abbrev.lisp        | 13 ++++++++-----
 hemlock/bit-stream.lisp    | 13 ++++++++-----
 hemlock/charmacs.lisp      | 13 ++++++++-----
 hemlock/cursor.lisp        | 13 ++++++++-----
 hemlock/dired.lisp         | 12 ++++++++----
 hemlock/diredcoms.lisp     | 13 ++++++++-----
 hemlock/echocoms.lisp      | 13 ++++++++-----
 hemlock/eval-server.lisp   | 13 ++++++++-----
 hemlock/filecoms.lisp      | 13 ++++++++-----
 hemlock/fill.lisp          | 13 ++++++++-----
 hemlock/group.lisp         | 13 ++++++++-----
 hemlock/htext2.lisp        | 13 ++++++++-----
 hemlock/htext3.lisp        | 13 ++++++++-----
 hemlock/input.lisp         | 13 ++++++++-----
 hemlock/key-event.lisp     | 13 ++++++++-----
 hemlock/killcoms.lisp      | 13 ++++++++-----
 hemlock/line.lisp          | 13 ++++++++-----
 hemlock/linimage.lisp      | 13 ++++++++-----
 hemlock/lispbuf.lisp       | 13 ++++++++-----
 hemlock/lispeval.lisp      | 13 ++++++++-----
 hemlock/lispmode.lisp      | 13 ++++++++-----
 hemlock/morecoms.lisp      | 13 ++++++++-----
 hemlock/pop-up-stream.lisp | 13 ++++++++-----
 hemlock/register.lisp      | 13 ++++++++-----
 hemlock/ring.lisp          | 13 ++++++++-----
 hemlock/rompsite.lisp      | 13 ++++++++-----
 hemlock/screen.lisp        | 13 ++++++++-----
 hemlock/search1.lisp       | 13 ++++++++-----
 hemlock/shell.lisp         | 13 ++++++++-----
 hemlock/spell-aug.lisp     | 13 ++++++++-----
 hemlock/spell-build.lisp   | 13 ++++++++-----
 hemlock/spell-corr.lisp    | 13 ++++++++-----
 hemlock/spell-rt.lisp      | 13 ++++++++-----
 hemlock/streams.lisp       | 13 ++++++++-----
 hemlock/struct.lisp        | 13 ++++++++-----
 hemlock/syntax.lisp        | 13 ++++++++-----
 hemlock/table.lisp         | 13 ++++++++-----
 hemlock/text.lisp          | 13 ++++++++-----
 hemlock/ts-stream.lisp     | 13 ++++++++-----
 hemlock/tty-disp-rt.lisp   | 13 ++++++++-----
 hemlock/tty-display.lisp   | 13 ++++++++-----
 hemlock/tty-stream.lisp    | 13 ++++++++-----
 42 files changed, 336 insertions(+), 209 deletions(-)

diff --git a/hemlock/abbrev.lisp b/hemlock/abbrev.lisp
index af95ba787..a4981d5e6 100644
--- a/hemlock/abbrev.lisp
+++ b/hemlock/abbrev.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/abbrev.lisp,v 1.1.1.3 1991/02/08 16:32:29 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;		     Hemlock Word Abbreviation Mode
diff --git a/hemlock/bit-stream.lisp b/hemlock/bit-stream.lisp
index fc4be3408..95d14af71 100644
--- a/hemlock/bit-stream.lisp
+++ b/hemlock/bit-stream.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/bit-stream.lisp,v 1.1.1.2 1991/02/08 16:33:05 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Some stuff to make streams that write out on bitmap hunks.
diff --git a/hemlock/charmacs.lisp b/hemlock/charmacs.lisp
index e37c94f8f..337b993d3 100644
--- a/hemlock/charmacs.lisp
+++ b/hemlock/charmacs.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/charmacs.lisp,v 1.1.1.4 1991/02/08 16:33:15 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Implementation specific character-hacking macros and constants.
diff --git a/hemlock/cursor.lisp b/hemlock/cursor.lisp
index e8144f18f..958fe3d54 100644
--- a/hemlock/cursor.lisp
+++ b/hemlock/cursor.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/cursor.lisp,v 1.1.1.3 1991/02/08 16:33:41 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;    Written by Rob MacLachlan
diff --git a/hemlock/dired.lisp b/hemlock/dired.lisp
index 535b5f8db..b0cccd556 100644
--- a/hemlock/dired.lisp
+++ b/hemlock/dired.lisp
@@ -1,10 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: dired -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/dired.lisp,v 1.1.1.3 1991/02/08 16:33:47 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; This file contains site dependent code for dired.
diff --git a/hemlock/diredcoms.lisp b/hemlock/diredcoms.lisp
index 34f4c25af..c05e8b34f 100644
--- a/hemlock/diredcoms.lisp
+++ b/hemlock/diredcoms.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC).
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/diredcoms.lisp,v 1.1.1.5 1991/02/08 16:33:52 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Simple directory editing support.
diff --git a/hemlock/echocoms.lisp b/hemlock/echocoms.lisp
index 066de83ee..1bf1155bc 100644
--- a/hemlock/echocoms.lisp
+++ b/hemlock/echocoms.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/echocoms.lisp,v 1.1.1.5 1991/02/08 16:34:09 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Echo area commands.
diff --git a/hemlock/eval-server.lisp b/hemlock/eval-server.lisp
index 36a96d25b..5dbde19c9 100644
--- a/hemlock/eval-server.lisp
+++ b/hemlock/eval-server.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC).
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/eval-server.lisp,v 1.1.1.5 1991/02/08 16:34:19 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; This file contains code for connecting to eval servers and some command
diff --git a/hemlock/filecoms.lisp b/hemlock/filecoms.lisp
index 4e57e75be..8c85603b4 100644
--- a/hemlock/filecoms.lisp
+++ b/hemlock/filecoms.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Package: Hemlock; Log: hemlock.log -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/filecoms.lisp,v 1.1.1.4 1991/02/08 16:34:26 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; This file contains file/buffer manipulating commands.
diff --git a/hemlock/fill.lisp b/hemlock/fill.lisp
index a120c6adf..8c1e9c5bb 100644
--- a/hemlock/fill.lisp
+++ b/hemlock/fill.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/fill.lisp,v 1.1.1.3 1991/02/08 16:34:37 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;    Written by Bill Chiles
diff --git a/hemlock/htext2.lisp b/hemlock/htext2.lisp
index 9ace9f869..0294632f0 100644
--- a/hemlock/htext2.lisp
+++ b/hemlock/htext2.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/htext2.lisp,v 1.1.1.2 1991/02/08 16:35:07 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; More Hemlock Text-Manipulation functions.
diff --git a/hemlock/htext3.lisp b/hemlock/htext3.lisp
index 27899017c..fb9397b87 100644
--- a/hemlock/htext3.lisp
+++ b/hemlock/htext3.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/htext3.lisp,v 1.1.1.2 1991/02/08 16:35:11 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; More Hemlock Text-Manipulation functions.
diff --git a/hemlock/input.lisp b/hemlock/input.lisp
index a76b08f72..2c2147ee2 100644
--- a/hemlock/input.lisp
+++ b/hemlock/input.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC).
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/input.lisp,v 1.1.1.4 1991/02/08 16:35:25 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; This file contains the code that handles input to Hemlock.
diff --git a/hemlock/key-event.lisp b/hemlock/key-event.lisp
index d12ff8632..3f78e875e 100644
--- a/hemlock/key-event.lisp
+++ b/hemlock/key-event.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: extensions -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/key-event.lisp,v 1.1.1.5 1991/02/08 16:35:37 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; This file implements key-events for representing editor input.  It also
diff --git a/hemlock/killcoms.lisp b/hemlock/killcoms.lisp
index ef8ac693e..5500d049d 100644
--- a/hemlock/killcoms.lisp
+++ b/hemlock/killcoms.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/killcoms.lisp,v 1.1.1.2 1991/02/08 16:35:51 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Killing and unkilling things.
diff --git a/hemlock/line.lisp b/hemlock/line.lisp
index f577bb5ed..520faf888 100644
--- a/hemlock/line.lisp
+++ b/hemlock/line.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/line.lisp,v 1.1.1.2 1991/02/08 16:35:54 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; This file contains definitions for the Line structure, and some 
diff --git a/hemlock/linimage.lisp b/hemlock/linimage.lisp
index bf04b9431..cbb9e0b38 100644
--- a/hemlock/linimage.lisp
+++ b/hemlock/linimage.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/linimage.lisp,v 1.1.1.4 1991/02/08 16:35:57 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;    Written by Rob MacLachlan
diff --git a/hemlock/lispbuf.lisp b/hemlock/lispbuf.lisp
index 843a30bd6..c79d9734f 100644
--- a/hemlock/lispbuf.lisp
+++ b/hemlock/lispbuf.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/lispbuf.lisp,v 1.1.1.4 1991/02/08 16:36:05 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Stuff to do a little lisp hacking in the editor's Lisp environment.
diff --git a/hemlock/lispeval.lisp b/hemlock/lispeval.lisp
index b79d8ae16..421031374 100644
--- a/hemlock/lispeval.lisp
+++ b/hemlock/lispeval.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Package: Hemlock; Log: hemlock.log -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC).
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/lispeval.lisp,v 1.1.1.3 1991/02/08 16:36:11 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; This file contains code for sending requests to eval servers and the
diff --git a/hemlock/lispmode.lisp b/hemlock/lispmode.lisp
index 864ccc993..bfca358d6 100644
--- a/hemlock/lispmode.lisp
+++ b/hemlock/lispmode.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/lispmode.lisp,v 1.1.1.4 1991/02/08 16:36:18 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Hemlock LISP Mode commands
diff --git a/hemlock/morecoms.lisp b/hemlock/morecoms.lisp
index 0962679f2..4f5b4b913 100644
--- a/hemlock/morecoms.lisp
+++ b/hemlock/morecoms.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/morecoms.lisp,v 1.1.1.4 1991/02/08 16:36:47 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Written by Bill Chiles and Rob MacLachlan.
diff --git a/hemlock/pop-up-stream.lisp b/hemlock/pop-up-stream.lisp
index 3549e2787..3e8467470 100644
--- a/hemlock/pop-up-stream.lisp
+++ b/hemlock/pop-up-stream.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/pop-up-stream.lisp,v 1.1.1.2 1991/02/08 16:36:58 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; This file contatins the stream operations for pop-up-displays.
diff --git a/hemlock/register.lisp b/hemlock/register.lisp
index bd1140261..879ca8fc9 100644
--- a/hemlock/register.lisp
+++ b/hemlock/register.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/register.lisp,v 1.1.1.3 1991/02/08 16:37:02 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Registers for holding text and positions.
diff --git a/hemlock/ring.lisp b/hemlock/ring.lisp
index 8840b62ef..82925b9f0 100644
--- a/hemlock/ring.lisp
+++ b/hemlock/ring.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: Hemlock.Log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/ring.lisp,v 1.1.1.2 1991/02/08 16:37:05 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;    Written by Rob MacLachlan
diff --git a/hemlock/rompsite.lisp b/hemlock/rompsite.lisp
index a4d5e6baf..5feedc7ef 100644
--- a/hemlock/rompsite.lisp
+++ b/hemlock/rompsite.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC).
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/rompsite.lisp,v 1.1.1.10 1991/02/08 16:37:08 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; "Site dependent" stuff for the editor while on the IBM RT PC machine.
diff --git a/hemlock/screen.lisp b/hemlock/screen.lisp
index 3c5d20e45..42fa817ea 100644
--- a/hemlock/screen.lisp
+++ b/hemlock/screen.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/screen.lisp,v 1.1.1.3 1991/02/08 16:37:20 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;    Written by Bill Chiles.
diff --git a/hemlock/search1.lisp b/hemlock/search1.lisp
index fd479cae3..7d8869147 100644
--- a/hemlock/search1.lisp
+++ b/hemlock/search1.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: Hemlock.Log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/search1.lisp,v 1.1.1.3 1991/02/08 16:37:27 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Searching and replacing functions for Hemlock.
diff --git a/hemlock/shell.lisp b/hemlock/shell.lisp
index c08cb0630..acf71f3f8 100644
--- a/hemlock/shell.lisp
+++ b/hemlock/shell.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/shell.lisp,v 1.1.1.4 1991/02/08 16:37:40 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Hemlock command level support for processes.
diff --git a/hemlock/spell-aug.lisp b/hemlock/spell-aug.lisp
index 315b40255..ed6c47d20 100644
--- a/hemlock/spell-aug.lisp
+++ b/hemlock/spell-aug.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Spell -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/spell-aug.lisp,v 1.1.1.2 1991/02/08 16:37:44 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;    Written by Bill Chiles
diff --git a/hemlock/spell-build.lisp b/hemlock/spell-build.lisp
index 0357b6ad3..660bc904b 100644
--- a/hemlock/spell-build.lisp
+++ b/hemlock/spell-build.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Spell -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/spell-build.lisp,v 1.1.1.5 1991/02/08 16:37:47 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;    Written by Bill Chiles
diff --git a/hemlock/spell-corr.lisp b/hemlock/spell-corr.lisp
index e55959561..a50e18f26 100644
--- a/hemlock/spell-corr.lisp
+++ b/hemlock/spell-corr.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Spell -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/spell-corr.lisp,v 1.1.1.5 1991/02/08 16:37:51 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;    Written by Bill Chiles
diff --git a/hemlock/spell-rt.lisp b/hemlock/spell-rt.lisp
index 9f908f14b..17f6fc500 100644
--- a/hemlock/spell-rt.lisp
+++ b/hemlock/spell-rt.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Spell -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/spell-rt.lisp,v 1.1.1.3 1991/02/08 16:37:56 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;    Written by Bill Chiles
diff --git a/hemlock/streams.lisp b/hemlock/streams.lisp
index edf1c84d2..303da19d5 100644
--- a/hemlock/streams.lisp
+++ b/hemlock/streams.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/streams.lisp,v 1.1.1.4 1991/02/08 16:38:09 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;    This file contains definitions of various types of streams used
diff --git a/hemlock/struct.lisp b/hemlock/struct.lisp
index 186e6da49..2657cc82e 100644
--- a/hemlock/struct.lisp
+++ b/hemlock/struct.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/struct.lisp,v 1.1.1.4 1991/02/08 16:38:14 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Structures and assorted macros for Hemlock.
diff --git a/hemlock/syntax.lisp b/hemlock/syntax.lisp
index 55764c09c..fe69e9aad 100644
--- a/hemlock/syntax.lisp
+++ b/hemlock/syntax.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/syntax.lisp,v 1.1.1.4 1991/02/08 16:38:20 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Hemlock syntax table routines.
diff --git a/hemlock/table.lisp b/hemlock/table.lisp
index 1e4b7dc9b..41ff70d85 100644
--- a/hemlock/table.lisp
+++ b/hemlock/table.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: HEMLOCK-INTERNALS -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (Scott.Fahlman@CS.CMU.EDU). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/table.lisp,v 1.1.1.2 1991/02/08 16:38:24 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Reluctantly written by Christopher Hoover
diff --git a/hemlock/text.lisp b/hemlock/text.lisp
index 94381dd94..c1fdeace1 100644
--- a/hemlock/text.lisp
+++ b/hemlock/text.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/text.lisp,v 1.1.1.2 1991/02/08 16:38:33 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;    Written by Bill Chiles
diff --git a/hemlock/ts-stream.lisp b/hemlock/ts-stream.lisp
index 3b750d5aa..9691b3a07 100644
--- a/hemlock/ts-stream.lisp
+++ b/hemlock/ts-stream.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Package: Hemlock; Log: hemlock.log -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC).
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/ts-stream.lisp,v 1.1.1.4 1991/02/08 16:38:39 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; This file implements typescript streams.
diff --git a/hemlock/tty-disp-rt.lisp b/hemlock/tty-disp-rt.lisp
index 3f8e5c74e..8d1a5a445 100644
--- a/hemlock/tty-disp-rt.lisp
+++ b/hemlock/tty-disp-rt.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/tty-disp-rt.lisp,v 1.1.1.2 1991/02/08 16:38:44 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;    Written by Bill Chiles.
diff --git a/hemlock/tty-display.lisp b/hemlock/tty-display.lisp
index f6c326b07..4850fb153 100644
--- a/hemlock/tty-display.lisp
+++ b/hemlock/tty-display.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/tty-display.lisp,v 1.1.1.5 1991/02/08 16:38:47 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;;    Written by Bill Chiles.
diff --git a/hemlock/tty-stream.lisp b/hemlock/tty-stream.lisp
index 448ea3be2..190eca26f 100644
--- a/hemlock/tty-stream.lisp
+++ b/hemlock/tty-stream.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock-Internals -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.
-;;; If you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC). 
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/tty-stream.lisp,v 1.1.1.2 1991/02/08 16:38:58 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; Some stuff to make streams that write out to terminal hunks.
diff --git a/hemlock/group.lisp b/hemlock/group.lisp
index 8c5eedbb1..d03c6714a 100644
--- a/hemlock/group.lisp
+++ b/hemlock/group.lisp
@@ -1,11 +1,14 @@
 ;;; -*- Log: hemlock.log; Package: Hemlock -*-
 ;;;
 ;;; **********************************************************************
-;;; This code was written as part of the Spice Lisp project at
-;;; Carnegie-Mellon University, and has been placed in the public domain.
-;;; Spice Lisp is currently incomplete and under active development.  If
-;;; you want to use this code or any part of Spice Lisp, please contact
-;;; Scott Fahlman (FAHLMAN@CMUC).
+;;; This code was written as part of the CMU Common Lisp project at
+;;; Carnegie Mellon University, and has been placed in the public domain.
+;;; If you want to use this code or any part of CMU Common Lisp, please contact
+;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /Volumes/share2/src/cmucl/cvs2git/cvsroot/src/hemlock/group.lisp,v 1.1.1.2 1991/02/08 16:34:45 ram Exp $")
+;;;
 ;;; **********************************************************************
 ;;;
 ;;; File group stuff for Hemlock.
-- 
GitLab